Scientific Article (CENTAUR) Data Mining Package
================================================


This package is a wrapper on `selenium <https://pypi.org/project/selenium/>`_, a package that "automates web browser interaction from Python". In this package, we add the following features:

* Automatically determine and install the correct chromedriver version, using webdriver-manager.
* Add a class used to identify where elements are located on the DOM
* Add a class that specifies if any extra processing should be done to the elements in the previous class, rather than just extract an attribute.
* Create helper classes to simplify the process of identifying elements
* Helper functions are included to make processing and storing data easier.

Although this package is tailored to data mining scientific literature, is can be used in other applications in data mining.
